@@ -15,22 +15,45 @@ impl AWSMachineTemplate {
     pub fn m5xlarge(name: &str) -> Self {
         Self::with_type(name, "m5.xlarge")
     }
+    pub fn m5dxlarge(name: &str) -> Self {
+        Self::with_type(name, "m5d.xlarge")
+    }
 
+    pub fn m5d4xlarge(name: &str) -> Self {
+        Self::with_type(name, "m5d.4xlarge")
+    }
+
+    pub fn m5d16large(name: &str) -> Self {
+        Self::with_type(name, "m5d.16xlarge")
+    }
+
+    pub fn m6gdxlarge(name: &str) -> Self {
+        Self::with_type(name, "m6gd.xlarge")
+    }
+
+    pub fn m6gd4xlarge(name: &str) -> Self {
+        Self::with_type(name, "m6gd.4xlarge")
+    }
+
+    #[must_use]
     pub fn ssh_key_name(mut self, name: &str) -> Self {
         self.spec.template.spec.ssh_key_name = Some(name.to_string());
         self
     }
 
+    #[must_use]
     pub fn iam_instance_profile(mut self, iam_instance_profile: &str) -> Self {
         self.spec.template.spec.iam_instance_profile = Some(iam_instance_profile.to_string());
         self
     }
 
+    #[must_use]
     pub fn public_ip(mut self, yes: bool) -> Self {
         self.spec.template.spec.public_ip = Some(yes);
         self
     }
 
+    #[must_use]
     pub fn namespace(self, namespace: &str) -> Self {
         Self {
             metadata: kube::core::ObjectMeta {
